[Ocfs2-commits] jlbec commits r2070 - in trunk: fs/configfs fs/ocfs2/cluster vendor/redhat vendor/suse

svn-commits at oss.oracle.com svn-commits at oss.oracle.com
Tue Mar 29 15:49:11 CST 2005


Author: jlbec
Signed-off-by: manish
Date: 2005-03-29 15:49:10 -0600 (Tue, 29 Mar 2005)
New Revision: 2070

Added:
   trunk/fs/configfs/configfs.h
   trunk/fs/configfs/configfs.txt
   trunk/fs/configfs/configfs_internal.h
Removed:
   trunk/fs/configfs/usysfs.h
   trunk/fs/configfs/usysfs.txt
   trunk/fs/configfs/usysfs_internal.h
Modified:
   trunk/fs/configfs/bobtest.c
   trunk/fs/configfs/dir.c
   trunk/fs/configfs/file.c
   trunk/fs/configfs/inode.c
   trunk/fs/configfs/mount.c
   trunk/fs/configfs/symlink.c
   trunk/fs/configfs/uobject.c
   trunk/fs/ocfs2/cluster/heartbeat.c
   trunk/fs/ocfs2/cluster/nodemanager.c
   trunk/vendor/redhat/ocfs2-2.6.9-EL.spec-generic.in
   trunk/vendor/suse/ocfs2-2.6.5.spec-generic.in
Log:

More usysfs->configfs rename stuff
o Fix RPM specfiles
o Change usysfs*.h to configfs*.h and update .c files to match.
o Change fs type to configfs.

Signed-off-by: manish



Modified: trunk/fs/configfs/bobtest.c
===================================================================
--- trunk/fs/configfs/bobtest.c	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/fs/configfs/bobtest.c	2005-03-29 21:49:10 UTC (rev 2070)
@@ -19,7 +19,7 @@
  * Based on sysfs:
  * 	sysfs is Copyright (C) 2001, 2002, 2003 Patrick Mochel
  *
- * usysfs Copyright (C) 2005 Oracle.  All rights reserved.
+ * configfs Copyright (C) 2005 Oracle.  All rights reserved.
  */
 
 #include <linux/init.h>
@@ -28,7 +28,7 @@
 #include <linux/slab.h>
 
 #include "uobject.h"
-#include "usysfs.h"
+#include "configfs.h"
 
 
 

Copied: trunk/fs/configfs/configfs.h (from rev 2069, trunk/fs/configfs/usysfs.h)

Copied: trunk/fs/configfs/configfs.txt (from rev 2069, trunk/fs/configfs/usysfs.txt)

Copied: trunk/fs/configfs/configfs_internal.h (from rev 2069, trunk/fs/configfs/usysfs_internal.h)

Modified: trunk/fs/configfs/dir.c
===================================================================
--- trunk/fs/configfs/dir.c	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/fs/configfs/dir.c	2005-03-29 21:49:10 UTC (rev 2070)
@@ -1,7 +1,7 @@
 /* -*- mode: c; c-basic-offset: 8; -*-
  * vim: noexpandtab sw=8 ts=8 sts=0:
  *
- * dir.c - Operations for usysfs directories.
+ * dir.c - Operations for configfs directories.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -21,7 +21,7 @@
  * Based on sysfs:
  * 	sysfs is Copyright (C) 2001, 2002, 2003 Patrick Mochel
  *
- * usysfs Copyright (C) 2005 Oracle.  All rights reserved.
+ * configfs Copyright (C) 2005 Oracle.  All rights reserved.
  */
 
 #undef DEBUG
@@ -34,8 +34,8 @@
 #include <linux/slab.h>
 
 #include "uobject.h"
-#include "usysfs.h"
-#include "usysfs_internal.h"
+#include "configfs.h"
+#include "configfs_internal.h"
 
 DECLARE_RWSEM(usysfs_rename_sem);
 static spinlock_t usysfs_linkage_lock = SPIN_LOCK_UNLOCKED;

Modified: trunk/fs/configfs/file.c
===================================================================
--- trunk/fs/configfs/file.c	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/fs/configfs/file.c	2005-03-29 21:49:10 UTC (rev 2070)
@@ -21,7 +21,7 @@
  * Based on sysfs:
  * 	sysfs is Copyright (C) 2001, 2002, 2003 Patrick Mochel
  *
- * usysfs Copyright (C) 2005 Oracle.  All rights reserved.
+ * configfs Copyright (C) 2005 Oracle.  All rights reserved.
  */
 
 #include <linux/fs.h>
@@ -32,8 +32,8 @@
 #include <asm/semaphore.h>
 
 #include "uobject.h"
-#include "usysfs.h"
-#include "usysfs_internal.h"
+#include "configfs.h"
+#include "configfs_internal.h"
 
 
 struct usysfs_buffer {

Modified: trunk/fs/configfs/inode.c
===================================================================
--- trunk/fs/configfs/inode.c	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/fs/configfs/inode.c	2005-03-29 21:49:10 UTC (rev 2070)
@@ -21,7 +21,7 @@
  * Based on sysfs:
  * 	sysfs is Copyright (C) 2001, 2002, 2003 Patrick Mochel
  *
- * usysfs Copyright (C) 2005 Oracle.  All rights reserved.
+ * configfs Copyright (C) 2005 Oracle.  All rights reserved.
  *
  * Please see Documentation/filesystems/usysfs.txt for more information.
  */
@@ -33,8 +33,8 @@
 #include <linux/backing-dev.h>
 
 #include "uobject.h"
-#include "usysfs.h"
-#include "usysfs_internal.h"
+#include "configfs.h"
+#include "configfs_internal.h"
 
 extern struct super_block * usysfs_sb;
 

Modified: trunk/fs/configfs/mount.c
===================================================================
--- trunk/fs/configfs/symlink.c	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/fs/configfs/symlink.c	2005-03-29 21:49:10 UTC (rev 2070)
@@ -1,7 +1,7 @@
 /* -*- mode: c; c-basic-offset: 8; -*-
  * vim: noexpandtab sw=8 ts=8 sts=0:
  *
- * symlink.c - operations for usysfs symlinks.
+ * symlink.c - operations for configfs symlinks.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -21,7 +21,7 @@
  * Based on sysfs:
  * 	sysfs is Copyright (C) 2001, 2002, 2003 Patrick Mochel
  *
- * usysfs Copyright (C) 2005 Oracle.  All rights reserved.
+ * configfs Copyright (C) 2005 Oracle.  All rights reserved.
  */
 
 #include <linux/version.h>
@@ -30,8 +30,8 @@
 #include <linux/namei.h>
 
 #include "uobject.h"
-#include "usysfs.h"
-#include "usysfs_internal.h"
+#include "configfs.h"
+#include "configfs_internal.h"
 
 static int object_depth(struct uobject * uobj)
 {

Modified: trunk/fs/configfs/uobject.c
===================================================================
--- trunk/fs/configfs/uobject.c	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/fs/configfs/uobject.c	2005-03-29 21:49:10 UTC (rev 2070)
@@ -22,7 +22,7 @@
 #include <linux/slab.h>
 
 #include "uobject.h"
-#include "usysfs.h"
+#include "configfs.h"
 
 
 static inline struct uobject * to_uobj(struct list_head * entry)

Deleted: trunk/fs/configfs/usysfs.h
===================================================================
--- trunk/fs/configfs/usysfs.h	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/fs/configfs/usysfs.h	2005-03-29 21:49:10 UTC (rev 2070)
@@ -1,112 +0,0 @@
-/* -*- mode: c; c-basic-offset: 8; -*-
- * vim: noexpandtab sw=8 ts=8 sts=0:
- *
- * usysfs.h - definitions for the device driver filesystem
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 021110-1307, USA.
- *
- * Based on sysfs:
- * 	sysfs is Copyright (C) 2001, 2002, 2003 Patrick Mochel
- *
- * usysfs Copyright (C) 2005 Oracle.  All rights reserved.
- *
- * Please see Documentation/filesystems/usysfs.txt for more information.
- */
-
-#ifndef _USYSFS_H_
-#define _USYSFS_H_
-
-#include <asm/atomic.h>
-#include <asm/semaphore.h>
-
-#include "uobject.h"
-
-struct module;
-
-struct usysfs_attribute {
-	char			* name;
-	struct module 		* owner;
-	mode_t			mode;
-};
-
-
-/*
- * If allow_link() exists, the object can symlink(2) out to other
- * objects.  If the object is a uset, it may support mkdir(2).  Uset
- * objects supply one of make_set() and make_object().  If the
- * object supports make_set(), one can create uset children.  If it
- * supports make_object(), one can create uobject children.  If it has
- * default_sets on uset->default_sets, it has automatically created
- * uset children.  default_sets may coexist alongsize make_set() or
- * make_object(), but if the uset wishes to have only default_sets 
- * children (disallowing mkdir(2)), it need not provide either function.
- * If the uset has commit(), it supports pending and commited (active)
- * objects.
- */
-struct usysfs_object_operations {
-	void (*release)(struct uobject *);
-	ssize_t	(*show_attribute)(struct uobject *, struct usysfs_attribute *,char *);
-	ssize_t	(*store_attribute)(struct uobject *,struct usysfs_attribute *,const char *, size_t);
-	int (*allow_link)(struct uobject *src, struct uobject *target);
-	int (*drop_link)(struct uobject *src, struct uobject *target);
-};
-
-struct usysfs_set_operations {
-	struct uobject *(*make_object)(struct uset *uset, const char *name);
-	struct uset *(*make_set)(struct uset *uset, const char *name);
-	int (*commit)(struct uobject *uobj);
-        void (*drop_object)(struct uset *uset, struct uobject *uobj);
-};
-
-
-
-/**
- * Use these macros to make defining attributes easier. See include/linux/device.h
- * for examples..
- */
-
-#define __ATTR(_name,_mode,_show,_store) { \
-	.attr = {.name = __stringify(_name), .mode = _mode, .owner = THIS_MODULE },	\
-	.show	= _show,					\
-	.store	= _store,					\
-}
-
-#define __ATTR_RO(_name) { \
-	.attr	= { .name = __stringify(_name), .mode = 0444, .owner = THIS_MODULE },	\
-	.show	= _name##_show,	\
-}
-
-#define __ATTR_NULL { .attr = { .name = NULL } }
-
-#define attr_name(_attr) (_attr).attr.name
-
-
-struct usysfs_subsystem {
-	struct uset		su_set;
-	struct semaphore	su_sem;
-};
-
-static inline struct usysfs_subsystem *to_usysfs_subsystem(struct uset *uset)
-{
-	return uset ?
-		container_of(uset, struct usysfs_subsystem, su_set) :
-		NULL;
-}
-
-int usysfs_register_subsystem(struct usysfs_subsystem *subsys);
-void usysfs_unregister_subsystem(struct usysfs_subsystem *subsys);
-
-#endif /* _USYSFS_H_ */

Deleted: trunk/fs/configfs/usysfs.txt
===================================================================
--- trunk/fs/configfs/usysfs.txt	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/fs/configfs/usysfs.txt	2005-03-29 21:49:10 UTC (rev 2070)
@@ -1,103 +0,0 @@
-
-usysfs - User-driven sysfs
-
-Joel Becker <joel.becker at oracle.com>
-
-Updated: 15 March 2005
-
-Copyright (c) 2005 Oracle Corporation,
-	Joel Becker <joel.becker at oracle.com>
-
-
-[What is usysfs?]
-
-usysfs is a ram-based filesystem initially based on sysfs.  It provides
-the converse of sysfs's functionality.  Where sysfs is a
-filesystem-based view of kernel objects, usysfs is a filesystem-based
-manager of kernel objects.
-
-With sysfs, an object is created in kernel (for example, when a device
-is discovered) and it is registered with sysfs.  Its attributes then
-appear in sysfs, allowing userspace to read the attributes via
-readdir(3)/read(2).  It may allow some attributes to be modified via
-write(2).  The important point is that the object is created and
-destroyed in kernel, the kernel controls the lifecycle of the sysfs
-representation, and sysfs is merely a window on all this.
-
-A usysfs object is created via an explicit userspace operation:
-mkdir(2).  It is destroyed via rmdir(2).  The attributes appear at
-mkdir(2) time, and can be read or modified via read(2) and write(2).
-As with sysfs, readdir(3) queries the list of objects and/or attributes.
-symlink(2) can be used to group objects together.  Unlike sysfs, the
-lifetime of the representation is completely driven by userspace.  The
-kernel modules backing the objects must respond to this.
-
-Both sysfs and usysfs can and should exist together on the same system.
-One is not a replacement for the other.
-
-[Using usysfs]
-
-usysfs can be compiled as a module or into the kernel.  You can access
-it by doing
-
-	mount -t usysfs none /usys
-
-The usysfs tree will be empty unless client modules are also loaded.
-These are modules that register their object types with usysfs.  Once a
-client module is loaded, it will appear as a subdirectory (or more than
-one) under /usys.  Like sysfs, the usysfs tree is always there, whether
-mounted on /usys or not.
-
-An object is created via mkdir(2).  The object's attributes will also
-appear at this time.  readdir(3) can determine what the attributes are,
-read(2) can query their default values, and write(2) can store new
-values.  Like sysfs, attributes should be ASCII text files, preferably
-with only one value per file.  The same efficiency caveats from sysfs
-apply.  Don't mix more than one attribute in one attribute file.
-
-Like sysfs, usysfs expects write(2) to store the entire buffer at once.
-When writing to usysfs attributes, userspace processes should first
-read the entire file, modify the portions they wish to change, and then
-write the entire buffer back.  Attribute files have a maximum size of
-one page (PAGE_SIZE, 4096 on i386).
-
-When an object needs to be destroyed, remove it with rmdir(2).  An
-object cannot be destroyed if any other object has a link to it (via
-symlink(2)).  Links can be removed via unlink(2).
-
-[Configuring FakeNBD: an Example]
-
-Imagine there's a Network Block Device (NBD) driver that allows you to
-access remote block devices.  Call it FakeNBD.  FakeNBD uses usysfs for
-its configuration.  Obviously, there will be a nice program that
-sysadmins use to configure FakeNBD, but somehow that program has to tell
-the driver about it.  Here's where usysfs comes in.
-
-When the FakeNBD driver is loaded, it registers itself with usysfs.
-readdir(3) sees this just fine:
-
-	# ls /usys
-	fakenbd
-
-A fakenbd connection can be created with mkdir(2).  The name is
-arbitrary, but likely the tool will make some use of the name.  Perhaps
-it is a uuid or a disk name:
-
-	# mkdir /usys/fakenbd/disk1
-	# ls /usys/fakenbd/disk1
-	target device rw
-
-The target attribute contains the IP address of the server FakeNBD will
-connect to.  The device attribute is the device on the server.
-Predictably, the rw attribute determines whether the connection is
-read-only or read-write.
-
-	# echo 10.0.0.1 > /usys/fakenbd/disk1/target
-	# echo /dev/sda1 > /usys/fakenbd/disk1/device
-	# echo 1 > /usys/fakenbd/disk1/rw
-
-That's it.  That's all there is.  Now the device is configured, via the
-shell no less.
-
-[Coding With usysfs]
-

Deleted: trunk/fs/configfs/usysfs_internal.h
===================================================================
--- trunk/fs/configfs/usysfs_internal.h	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/fs/configfs/usysfs_internal.h	2005-03-29 21:49:10 UTC (rev 2070)
@@ -1,146 +0,0 @@
-/* -*- mode: c; c-basic-offset:8; -*-
- * vim: noexpandtab sw=8 ts=8 sts=0:
- *
- * usysfs_internal.h - Internal stuff for usysfs
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 021110-1307, USA.
- *
- * Based on sysfs:
- * 	sysfs is Copyright (C) 2001, 2002, 2003 Patrick Mochel
- *
- * usysfs Copyright (C) 2005 Oracle.  All rights reserved.
- */
-
-#include <linux/version.h>
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0)
-#include "linux/compat_libfs.h"
-#endif
-#include <linux/slab.h>
-#include <linux/list.h>
-
-struct usysfs_dirent {
-	atomic_t		s_count;
-	struct list_head	s_sibling;
-	struct list_head	s_children;
-	struct list_head	s_links;
-	void 			* s_element;
-	int			s_type;
-	umode_t			s_mode;
-	struct dentry		* s_dentry;
-};
-
-#define USYSFS_ROOT		0x0001
-#define USYSFS_DIR		0x0002
-#define USYSFS_UOBJ_ATTR 	0x0004
-#define USYSFS_UOBJ_LINK 	0x0020
-#define USYSFS_USET_DIR		0x0040
-#define USYSFS_USET_DEFAULT	0x0080
-#define USYSFS_NOT_PINNED	(USYSFS_UOBJ_ATTR)
-
-extern struct vfsmount * usysfs_mount;
-
-extern int usysfs_is_root(struct uobject *uobj);
-
-extern struct inode * usysfs_new_inode(mode_t mode);
-extern int usysfs_create(struct dentry *, int mode, int (*init)(struct inode *));
-
-extern int usysfs_create_file(struct uobject *, const struct usysfs_attribute *);
-extern int usysfs_make_dirent(struct usysfs_dirent *, struct dentry *, void *,
-				umode_t, int);
-extern struct dentry * usysfs_get_dentry(struct dentry *, const char *);
-
-extern int usysfs_add_file(struct dentry *, const struct usysfs_attribute *, int);
-extern void usysfs_hash_and_remove(struct dentry * dir, const char * name);
-
-extern const unsigned char * usysfs_get_name(struct usysfs_dirent *sd);
-extern void usysfs_drop_dentry(struct usysfs_dirent *sd, struct dentry *parent);
-
-extern int usysfs_pin_fs(void);
-extern void usysfs_release_fs(void);
-
-extern struct rw_semaphore usysfs_rename_sem;
-extern struct super_block * usysfs_sb;
-extern struct file_operations usysfs_dir_operations;
-extern struct file_operations usysfs_file_operations;
-extern struct file_operations bin_fops;
-extern struct inode_operations usysfs_dir_inode_operations;
-extern struct inode_operations usysfs_symlink_inode_operations;
-
-extern int usysfs_symlink(struct inode *dir, struct dentry *dentry,
-			  const char *symname);
-extern int usysfs_unlink(struct inode *dir, struct dentry *dentry);
-
-struct usysfs_symlink {
-	struct list_head sl_list;
-	struct uobject *sl_target;
-};
-
-extern int usysfs_create_link(struct usysfs_symlink *sl,
-			      struct dentry *parent,
-			      struct dentry *dentry);
-
-static inline struct uobject * to_uobj(struct dentry * dentry)
-{
-	struct usysfs_dirent * sd = dentry->d_fsdata;
-	return ((struct uobject *) sd->s_element);
-}
-
-static inline struct usysfs_attribute * to_attr(struct dentry * dentry)
-{
-	struct usysfs_dirent * sd = dentry->d_fsdata;
-	return ((struct usysfs_attribute *) sd->s_element);
-}
-
-static inline struct uobject *usysfs_get_uobject(struct dentry *dentry)
-{
-	struct uobject * uobj = NULL;
-
-	spin_lock(&dcache_lock);
-	if (!d_unhashed(dentry)) {
-		struct usysfs_dirent * sd = dentry->d_fsdata;
-		if (sd->s_type & USYSFS_UOBJ_LINK) {
-			struct usysfs_symlink * sl = sd->s_element;
-			uobj = uobject_get(sl->sl_target);
-		} else
-			uobj = uobject_get(sd->s_element);
-	}
-	spin_unlock(&dcache_lock);
-
-	return uobj;
-}
-
-static inline void release_usysfs_dirent(struct usysfs_dirent * sd)
-{
-	if (!(sd->s_type & USYSFS_ROOT))
-		kfree(sd);
-}
-
-static inline struct usysfs_dirent * usysfs_get(struct usysfs_dirent * sd)
-{
-	if (sd) {
-		WARN_ON(!atomic_read(&sd->s_count));
-		atomic_inc(&sd->s_count);
-	}
-	return sd;
-}
-
-static inline void usysfs_put(struct usysfs_dirent * sd)
-{
-	WARN_ON(!atomic_read(&sd->s_count));
-	if (atomic_dec_and_test(&sd->s_count))
-		release_usysfs_dirent(sd);
-}
-

Modified: trunk/fs/ocfs2/cluster/heartbeat.c
===================================================================
--- trunk/fs/ocfs2/cluster/heartbeat.c	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/fs/ocfs2/cluster/heartbeat.c	2005-03-29 21:49:10 UTC (rev 2070)
@@ -56,7 +56,7 @@
 #include <linux/file.h>
 #include <linux/bitops.h>
 #include <linux/kthread.h>
-#include "usysfs.h"
+#include "configfs.h"
 
 #include <asm/uaccess.h>
 #include <asm/bitops.h>

Modified: trunk/fs/ocfs2/cluster/nodemanager.c
===================================================================
--- trunk/fs/ocfs2/cluster/nodemanager.c	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/fs/ocfs2/cluster/nodemanager.c	2005-03-29 21:49:10 UTC (rev 2070)
@@ -65,7 +65,7 @@
 #include "nodemanager.h"
 #include "heartbeat.h"
 
-#include "usysfs.h"
+#include "configfs.h"
 
 #ifndef __user
 #define __user

Modified: trunk/vendor/redhat/ocfs2-2.6.9-EL.spec-generic.in
===================================================================
--- trunk/vendor/redhat/ocfs2-2.6.9-EL.spec-generic.in	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/vendor/redhat/ocfs2-2.6.9-EL.spec-generic.in	2005-03-29 21:49:10 UTC (rev 2070)
@@ -114,8 +114,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean
@@ -133,8 +133,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}smp/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean
@@ -152,8 +152,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}hugemem/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean

Modified: trunk/vendor/suse/ocfs2-2.6.5.spec-generic.in
===================================================================
--- trunk/vendor/suse/ocfs2-2.6.5.spec-generic.in	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/vendor/suse/ocfs2-2.6.5.spec-generic.in	2005-03-29 21:49:10 UTC (rev 2070)
@@ -277,8 +277,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}-default/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean
@@ -295,8 +295,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}-smp/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean
@@ -313,8 +313,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}-bigsmp/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean
@@ -331,8 +331,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}-64k-pagesize/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean
@@ -349,8 +349,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}-sn2/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean
@@ -367,8 +367,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}-iseries64/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean
@@ -385,8 +385,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}-pmac64/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean
@@ -403,8 +403,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}-pseries64/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean
@@ -421,8 +421,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}-s390/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean
@@ -439,8 +439,8 @@
 INST_MODLIB="${RPM_BUILD_ROOT}/lib/modules/%{kver}-s390x/kernel"
 mkdir -p "${INST_MODLIB}/fs/ocfs2"
 mv "${EXTRA_MODLIB}"/ocfs2*.ko "${INST_MODLIB}/fs/ocfs2/"
-mkdir -p "${INST_MODLIB}/fs/usysfs"
-mv "${EXTRA_MODLIB}"/usysfs.ko "${INST_MODLIB}/fs/usysfs/"
+mkdir -p "${INST_MODLIB}/fs/configfs"
+mv "${EXTRA_MODLIB}"/configfs.ko "${INST_MODLIB}/fs/configfs/"
 rm "${EXTRA_MODLIB}"/*.ko
 
 make clean



More information about the Ocfs2-commits mailing list
--- trunk/fs/configfs/mount.c	2005-03-29 21:28:38 UTC (rev 2069)
+++ trunk/fs/configfs/mount.c	2005-03-29 21:49:10 UTC (rev 2070)
@@ -1,7 +1,7 @@
 /* -*- mode: c; c-basic-offset: 8; -*-
  * vim: noexpandtab sw=8 ts=8 sts=0:
  *
  * mount.c - operations for initializing and mounting usysfs.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -21,7 +21,7 @@
  * Based on sysfs:
  * 	sysfs is Copyright (C) 2001, 2002, 2003 Patrick Mochel
  *
- * usysfs Copyright (C) 2005 Oracle.  All rights reserved.
+ * configfs Copyright (C) 2005 Oracle.  All rights reserved.
  */
 
 #define DEBUG 1
@@ -33,8 +33,8 @@
 #include <linux/init.h>
 
 #include "uobject.h"
-#include "usysfs.h"
-#include "usysfs_internal.h"
+#include "configfs.h"
+#include "configfs_internal.h"
 
 /* Random magic number */
 #define UUSYSFS_MAGIC 0x62656570
@@ -124,7 +124,7 @@
 
 static struct file_system_type usysfs_fs_type = {
 	.owner		= THIS_MODULE,
-	.name		= "usysfs",
+	.name		= "configfs",
 	.get_sb		= usysfs_get_sb,
 	.kill_sb	= kill_litter_super,
 };
@@ -134,12 +134,12 @@
 	return (usysfs_fill_super(sb, data, silent) < 0) ? NULL : sb;
 }
 
-static DECLARE_FSTYPE(usysfs_fs_type, "usysfs", usysfs_read_super, FS_SINGLE);
+static DECLARE_FSTYPE(usysfs_fs_type, "configfs", usysfs_read_super, FS_SINGLE);
 #endif
 
 int usysfs_pin_fs(void)
 {
-	return simple_pin_fs("usysfs", &usysfs_mount,
+	return simple_pin_fs("configfs", &usysfs_mount,
 			     &usysfs_mnt_count);
 }
 
@@ -1,7 +1,7 @@
  * vim: noexpandtab sw=8 ts=8 sts=0:
  *
- * mount.c - operations for initializing and mounting usysfs.
+ * mount.c - operations for initializing and mounting configfs.
  *
  * This program is free software; you can redistribute it and/or

Modified: trunk/fs/configfs/symlink.c
===================================================================